[tor-commits] [bridgedb/develop] Rename b.e.server.MailContext to b.e.server.MailServerContext.
isis at torproject.org
isis at torproject.org
Fri Jun 6 20:40:38 UTC 2014
commit 2e5f94f4aaf4187f5bc566d3d9028fc10749fe05
Author: Isis Lovecruft <isis at torproject.org>
Date: Mon Jun 2 20:53:37 2014 +0000
Rename b.e.server.MailContext to b.e.server.MailServerContext.
---
lib/bridgedb/email/server.py | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
diff --git a/lib/bridgedb/email/server.py b/lib/bridgedb/email/server.py
index c526852..d27b525 100644
--- a/lib/bridgedb/email/server.py
+++ b/lib/bridgedb/email/server.py
@@ -46,7 +46,7 @@ from bridgedb.parse.addr import UnsupportedDomain
from bridgedb.parse.addr import canonicalizeEmailDomain
-class MailContext(object):
+class MailServerContext(object):
"""Helper object that holds information used by email subsystem.
:ivar str username: Reject any RCPT TO lines that aren't to this
@@ -103,12 +103,12 @@ class MailContext(object):
"""Build a map for all email provider domains from which we will accept
emails to their canonical domain name.
- .. note:: Be sure that ``MailContext.domainRules`` and
- ``MailContext.domainMap`` are set appropriately before calling
+ .. note:: Be sure that ``MailServerContext.domainRules`` and
+ ``MailServerContext.domainMap`` are set appropriately before calling
this method.
This method is automatically called during initialisation, and the
resulting domain map is stored as ``MailContext.canon``.
:rtype: dict
:returns: A dictionary which maps all domains and subdomains which we
More information about the tor-commits
@@ -103,12 +103,12 @@ class MailContext(object):
this method.
This method is automatically called during initialisation, and the
- resulting domain map is stored as ``MailContext.canon``.
+ resulting domain map is stored as ``MailServerContext.canon``.
:rtype: dict
:returns: A dictionary which maps all domains and subdomains which we
mailing list